<?php

namespace Drupal\harmonize\Harmonizer\EntityHarmonizer;

use Drupal;
use Drupal\Core\Entity\EntityMalformedException;

/**
 * Handles harmonization exceptions for Node entities.
 *
 * @property \Drupal\node\Entity\Node $entity
 *
 * @package Drupal\harmonize\Harmonizer\EntityHarmonizer
 */
final class NodeEntityHarmonizer extends EntityHarmonizer {

  /**
   * {@inheritdoc}
   */
  protected function getHarmonizedData() {
    $data = parent::getHarmonizedData();

    if (!is_array($data)) {
      $data = ['content' => $data];
    }

    // Get Entity Title if it exists.
    if ($this->entity->getTitle() !== NULL) {
      $data['title'] = $this->entity->getTitle();
    }

    // Add URL information if node is not new.
    if (!$this->entity->isNew()) {
      try {
        $url = $this->entity->toUrl('canonical', ['absolute' => FALSE]);
        $data['href'] = $url;
      }
      catch (EntityMalformedException $exception) {
        Drupal::logger('harmonize')->error($exception->getMessage());
      }
    }

    // Add other relevant information for nodes.
    $data['creation_date'] = $this->entity->getCreatedTime();

    /* @var \Drupal\user\Entity\User */
    $data['drupal_author'] = $this->harmonizeService->harmonize($this->entity->getOwner());

    return $data;
  }

}
