<?php

namespace Drupal\harmonize\Harmonizer\EntityHarmonizer;

use Drupal;
use Drupal\Core\Entity\EntityMalformedException;

/**
 * Handles harmonization exceptions for TaxonomyTerm entities.
 *
 * @property \Drupal\taxonomy\Entity\Term $entity
 *
 * @package Drupal\harmonize\Harmonizer\TaxonomyTermEntityHarmonizer
 */
final class TaxonomyTermEntityHarmonizer extends EntityHarmonizer {

  /**
   * {@inheritdoc}
   */
  protected function getHarmonizedData() {
    // Run the EntityHarmonizerBase function. No exceptions here.
    $data = parent::getHarmonizedData();

    // Add term title to the processed data.
    $data['name'] = $this->entity->getName();

    // Add term description to the processed data.
    $data['description'] = $this->entity->getDescription();

    // Add term weight to the processed data.
    $data['weight'] = $this->entity->getWeight();

    // Add URL information if node is not new.
    if (!$this->entity->isNew()) {
      try {
        $url = $this->entity->toUrl('canonical');
        $data['href'] = $url;
      }
      catch (EntityMalformedException $exception) {
        Drupal::logger('harmonize')->error($exception->getMessage());
      }
    }

    return $data;
  }

}
